import countryData from './CountryData';
var MapBuilder = /** @class */ (function () {
    function MapBuilder() {
        var _this = this;
        this.width = 900;
        this.height = 450;
        this.normalColor = 'white';
        this.highlightColor = 'red';
        this.namesOfCountriesToHighlight = [];
        this.setWidth = function (width) {
            _this.width = width;
            return _this;
        };
        this.setHeight = function (height) {
            _this.height = height;
            return _this;
        };
        this.setNormalColor = function (normalColor) {
            _this.normalColor = normalColor;
            return _this;
        };
        this.setHighlightColor = function (highlightColor) {
            _this.highlightColor = highlightColor;
            return _this;
        };
        this.addCountryToHighlight = function (countryName) {
            _this.namesOfCountriesToHighlight.push(countryName);
            return _this;
        };
        this.build = function () {
            var namedview = "\n      <sodipodi:namedview\n        pagecolor=\"#ffffff\"\n        bordercolor=\"#666666\"\n        borderopacity=\"1\"\n        objecttolerance=\"10\"\n        gridtolerance=\"10\"\n        guidetolerance=\"10\"\n        inkscape:pageopacity=\"0\"\n        inkscape:pageshadow=\"2\"\n        inkscape:window-width=\"1920\"\n        inkscape:window-height=\"1137\"\n        id=\"namedview231\"\n        showgrid=\"false\"\n        inkscape:zoom=\"1.144\"\n        inkscape:cx=\"593.00732\"\n        inkscape:cy=\"460.46398\"\n        inkscape:window-x=\"1192\"\n        inkscape:window-y=\"118\"\n        inkscape:window-maximized=\"1\"\n        inkscape:current-layer=\"svg2\"\n      />";
            var defs = "\n      <defs id=\"defs4\">\n        <style\n          type=\"text/css\"\n          id=\"style6\">path { fill-rule: evenodd; }\n        </style>\n      </defs>";
            var metedata = "\n      <metadata id=\"metadata8\">\n        <views\n            id=\"views10\">\n          <view\n              h=\"1001\"\n              padding=\"0\"\n              w=\"2000\"\n              id=\"view12\">\n            <proj\n                flip=\"auto\"\n                id=\"robinson\"\n                lon0=\"100.0\" />\n            <bbox\n                h=\"2233.1\"\n                w=\"5271.17\"\n                x=\"-2635.59\"\n                y=\"-1308.06\"\n                id=\"bbox15\" />\n          </view>\n        </views>\n        <rdf:RDF>\n          <cc:Work\n              rdf:about=\"\">\n            <dc:format>image/svg+xml</dc:format>\n            <dc:type\n                rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\" />\n            <dc:title />\n          </cc:Work>\n        </rdf:RDF>\n      </metadata>";
            var countryPaths = _this._buildCountryPaths();
            var svg = "\n      <svg\n        xmlns:dc=\"http://purl.org/dc/elements/1.1/\"\n        xmlns:cc=\"http://creativecommons.org/ns#\"\n        xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\"\n        xmlns:svg=\"http://www.w3.org/2000/svg\"\n        xmlns=\"http://www.w3.org/2000/svg\"\n        xmlns:sodipodi=\"http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd\"\n        xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\"\n        enable_background=\"new 0 0 2000 1001\"\n        pretty_print=\"False\"\n        style=\"stroke-linejoin: round; stroke:#000; fill: none;\"\n        version=\"1.1\"\n        viewBox=\"0 0 2000 1001\"\n        width=\"" + _this.width + "px\"\n        height=\"" + _this.height + "px\"\n        id=\"svg2\"\n        inkscape:version=\"0.48.4 r9939\"\n        sodipodi:docname=\"world.svg\"\n      >\n        " + namedview + "\n        " + defs + "\n        " + metedata + "\n        " + countryPaths + "\n      </svg>";
            return svg;
        };
        this._buildCountryPaths = function () {
            var countryPaths = '';
            countryData.countryInfos.forEach(function (countryInfo) {
                var highlight = countryData.matchesCountry(countryInfo, _this.namesOfCountriesToHighlight);
                var fillColor = highlight ? _this.highlightColor : _this.normalColor;
                var countryPath = _this._buildCountryPath(countryInfo, fillColor);
                countryPaths += countryPath;
            });
            return countryPaths;
        };
        this._buildCountryPath = function (countryInfo, fillColor) {
            return "<path\n      inkscape:connector-curvature=\"0\"\n      id=\"" + countryInfo.id + "\"\n      data-name=\"" + countryInfo.name + "\"\n      data-id=\"" + countryInfo.id + "\"\n      d=\"" + countryInfo.path + "\"\n      style=\"fill:" + fillColor + ";fill-rule:evenodd\"\n    />";
        };
    }
    return MapBuilder;
}());
export default MapBuilder;
//# sourceMappingURL=MapBuilder.js.map